==> koshoten.net-2.2.0.tar.gz: koshoten-net/catalog/includes/languages/japanese/advanced_search.php <==
<?php
/*
  $Id: advanced_search.php,v 1.3 2006/07/16 05:09:35 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

define('NAVBAR_TITLE', 'ܺٸ');
define('HEADING_TITLE', 'ܺٸ');

define('HEADING_SEARCH_CRITERIA', 'ܺٸ');

define('ENTRY_PRODUCTS_NAME', '̾:');
define('TEXT_SEARCH_IN_SUBTITLE_SERIES_TITLE', 'ꡢ꡼̾õ');
define('TEXT_SEARCH_IN_SUBTITLE', '꤫õ');
define('TEXT_SEARCH_IN_SERIES_TITLE', '꡼̾õ');
define('ENTRY_PRODUCTS_AUTHOR', '̾:');
define('ENTRY_PRODUCTS_PUBLISHERS', 'Ǽ̾:');
define('ENTRY_PRODUCTS_ISBN', 'ISBN:');
define('TEXT_SEARCH_IN_DESCRIPTION', 'õ');
define('ENTRY_CATEGORIES', 'ƥ꡼:');
define('ENTRY_INCLUDE_SUBCATEGORIES', '֥ƥ꡼դ');
define('ENTRY_MANUFACTURERS', KN_CFG_USE_MANUFACTURERS . ':');
define('ENTRY_PRICE_FROM', 'ʡʺ:');
define('ENTRY_PRICE_TO', 'ʡʺǹ:');
define('ENTRY_DATE_FROM', 'Ͽʳ:');
define('ENTRY_DATE_TO', 'Ͽʽλ:');

define('TEXT_SEARCH_HELP_LINK', '<u>ܺٸλȤ</u> [?]');

define('TEXT_ALL_CATEGORIES', 'ƥ꡼');
define('TEXT_ALL_MANUFACTURERS', '' . KN_CFG_USE_MANUFACTURERS);

define('HEADING_SEARCH_HELP', 'ܺٸλȤ');
define('TEXT_SEARCH_HELP', 'ƹǤϡñʸ AND  OR Ƕڤ뤳ȤǤޤ<br /><br />㤨С<strong>ʳ AND </strong>ϤȡξñդʤõޤФơ<strong> OR ߧ߷</strong>Ϥȡɤ餫ñդʤõޤ<br /><br />ĤñǰϤǸȡϤʸΤ˰פΤõޤ<br /><br />㤨С<strong>" ʳ"</strong>ȤƸȡΤޤޤʸդʤõȤǤޤ<br /><br />̤ѤơŪȤ߹碌ꤹ뤳ȤǤޤ<br /><br />㤨С<strong> AND (ʪ OR  OR " ʳ")</strong>ȤƸȡ"" + "ʪ"""Τ!" ʳ"Ȥɤդʤõޤ<br /><br />ƹܴ֤ϡANDˤʤޤ<br /><br />㤨С̾<strong>ǭ</strong>̾<strong></strong>Ϥȡ̾"ǭ"դޤ졢̾""դޤ뾦ʤõޤ');
define('TEXT_CLOSE_WINDOW', 'ɥĤ [x]');

define('JS_AT_LEAST_ONE_INPUT', '* ΥեɤΤ줫ϤƤ:\n    \n    ǡϿ()\n    ǡϿ(λ)\n    ()\n    (ǹ)\n');
define('JS_INVALID_FROM_DATE', '* Ͽ()ޤ\n');
define('JS_INVALID_TO_DATE', '* Ͽ(λ)ޤ\n');
define('JS_TO_DATE_LESS_THAN_FROM_DATE', '* Ͽ(λ)Ͽ()ʹߤϤƤ\n');
define('JS_PRICE_FROM_MUST_BE_NUM', '* ()ϿϤƤ\n');
define('JS_PRICE_TO_MUST_BE_NUM', '* (ǹ)ϿϤƤ\n');
define('JS_PRICE_TO_LESS_THAN_PRICE_FROM', '* (ǹ)ϲ()ʾϤƤ\n');
define('JS_INVALID_KEYWORDS', '* ɤޤ\n');
?>

==> koshoten.net-2.2.2.tar.gz: koshoten-net/catalog/includes/languages/japanese/advanced_search.php <==
<?php
/*
  $Id: advanced_search.php,v 1.4 2009/04/14 09:31:38 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

define('NAVBAR_TITLE', 'ܺٸ');
define('HEADING_TITLE', 'ܺٸ');

define('HEADING_SEARCH_CRITERIA', 'ܺٸ');

define('ENTRY_PRODUCTS_NAME', '̾:');
define('TEXT_SEARCH_IN_SUBTITLE_SERIES_TITLE', 'ꡢ꡼̾õ');
define('TEXT_SEARCH_IN_SUBTITLE', '꤫õ');
define('TEXT_SEARCH_IN_SERIES_TITLE', '꡼̾õ');
define('ENTRY_PRODUCTS_AUTHOR', '̾:');
define('ENTRY_PRODUCTS_PUBLISHERS', 'Ǽ̾:');
define('ENTRY_PRODUCTS_ISBN', 'ISBN:');
define('TEXT_SEARCH_IN_DESCRIPTION', 'õ');
define('ENTRY_CATEGORIES', 'ƥ꡼:');
define('ENTRY_INCLUDE_SUBCATEGORIES', '֥ƥ꡼դ');
define('ENTRY_MANUFACTURERS', KN_CFG_USE_MANUFACTURERS . ':');
define('ENTRY_PRICE_FROM', 'ʡʺ:');
define('ENTRY_PRICE_TO', 'ʡʺǹ:');
define('ENTRY_DATE_FROM', 'Ͽʳ:');
define('ENTRY_DATE_TO', 'Ͽʽλ:');

define('TEXT_SEARCH_HELP_LINK', '<u>ܺٸλȤ</u> [?]');

define('TEXT_ALL_CATEGORIES', 'ƥ꡼');
define('TEXT_ALL_MANUFACTURERS', '' . KN_CFG_USE_MANUFACTURERS);

define('HEADING_SEARCH_HELP', 'ܺٸλȤ');
define('TEXT_SEARCH_HELP', 'ƹǤϡñʸ AND  OR Ƕڤ뤳ȤǤޤ<br /><br />㤨С<strong>ʳ AND </strong>ϤȡξñդʤõޤФơ<strong> OR ߧ߷</strong>Ϥȡɤ餫ñդʤõޤ<br /><br />ĤñǰϤǸȡϤʸΤ˰פΤõޤ<br /><br />㤨С<strong>" ʳ"</strong>ȤƸȡΤޤޤʸդʤõȤǤޤ<br /><br />̤ѤơŪȤ߹碌ꤹ뤳ȤǤޤ<br /><br />㤨С<strong> AND (ʪ OR  OR " ʳ")</strong>ȤƸȡ"" + "ʪ"""Τ!" ʳ"Ȥɤդʤõޤ<br /><br />ƹܴ֤ϡANDˤʤޤ<br /><br />㤨С̾<strong>ǭ</strong>̾<strong></strong>Ϥȡ̾"ǭ"դޤ졢̾""դޤ뾦ʤõޤ');
define('TEXT_CLOSE_WINDOW', 'ɥĤ [x]');

define('JS_AT_LEAST_ONE_INPUT', '* θܤΤ줫ϤƤ\n');
define('JS_INVALID_FROM_DATE', '* Ͽ()ޤ\n');
define('JS_INVALID_TO_DATE', '* Ͽ(λ)ޤ\n');
define('JS_TO_DATE_LESS_THAN_FROM_DATE', '* Ͽ(λ)Ͽ()ʹߤϤƤ\n');
define('JS_PRICE_FROM_MUST_BE_NUM', '* ()ϿϤƤ\n');
define('JS_PRICE_TO_MUST_BE_NUM', '* (ǹ)ϿϤƤ\n');
define('JS_PRICE_TO_LESS_THAN_PRICE_FROM', '* (ǹ)ϲ()ʾϤƤ\n');
define('JS_INVALID_KEYWORDS', '* ɤޤ\n');
?>
